@@ -1,10 +1,20 @@
 from multiprocessing import AuthenticationError
-from .const import *
-from .compare_it_model import CompareItModel
+#from .const import *
+#from .compare_it_model import CompareItModel
 import time
 import json
 import aiohttp
 
+CALLTIMEOUT = 5
+RESPONSE = 'response'
+DATETIME = "dt"
+ENDPOINT = 'https://dev2.mittsmartahus.se/api/0/'
+
+class CompareItModel:
+    endpoint:str = ENDPOINT
+    cachedresponse:dict = {}
+
+
 class CompareIt:
     def __init__(self, username, password):
         self._username = username
@@ -38,6 +48,7 @@ class CompareIt:
 
     async def async_get_entity(self, uuid):
         uri = 'object/' + uuid
+        uri = await self.async_set_uri(uri)
         return await self.async_get_internal(uri)
         
     async def async_set_entity(self, uuid, value) -> bool:
@@ -82,7 +93,4 @@ class CompareIt:
                     return 'Error!'
     
     async def async_set_uri(self, uri) -> str:
-        return self._model.endpoint + uri
-
-
-
+        return self._model.endpoint + uri
\ No newline at end of file
